package com.ynet.life.sujrb.file.parser;

import com.ynet.gene.core.Context;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.BatchRFKDDataDetailSummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.io.FileInputStream;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.regex.Pattern;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BatchRFKDDataDetailImport.class */
public class BatchRFKDDataDetailImport implements BatchFileParserInterface {
    private String formatter;
    private Context context;

    public BatchRFKDDataDetailImport() {
    }

    public BatchRFKDDataDetailImport(String formatter) {
        this.formatter = formatter;
    }

    public Context getContext() {
        return this.context;
    }

    public void setContext(Context context) {
        this.context = context;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        try {
            POIFSFileSystem file = new POIFSFileSystem(new FileInputStream(filePathName));
            HSSFWorkbook workBook = new HSSFWorkbook(file);
            BatchRFKDDataDetailSummary result = new BatchRFKDDataDetailSummary();
            try {
                HSSFSheet sheet = workBook.getSheetAt(0);
                HSSFRow summaryRow = sheet.getRow(0);
                int rowIndex = 2;
                HSSFRow recordRowTemp = sheet.getRow(2);
                if (getCellContent(recordRowTemp, 0, true).trim().equals("结束")) {
                    throw new TranFailException("excelError", "文件解析失败");
                }
                if (summaryRow.getPhysicalNumberOfCells() != 44) {
                    throw new TranFailException("excelError", "模板错误");
                }
                while (true) {
                    int i = rowIndex;
                    rowIndex++;
                    HSSFRow recordRow = sheet.getRow(i);
                    if (!getCellContent(recordRow, 0, true).trim().equals("结束")) {
                        if (this.formatter == null) {
                            result.addRecord(getRecordMap(recordRow));
                        } else {
                            result.addRecord(getRecordMap(recordRow, this.formatter));
                        }
                    } else {
                        return result;
                    }
                }
            } catch (Exception ex) {
                Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
                throw new TranFailException("EBCB0504", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", false);
            }
        } catch (OfficeXmlFileException e) {
            Trace.logError("LifeFile", "Excel版本过高", e);
            throw new TranFailException("excelError", "Excel版本过高");
        } catch (IOException ex2) {
            Trace.logError("LifeFile", "文件读取失败", ex2);
            throw new TranFailException("excelError", "文件读取失败");
        }
    }

    private Map getRecordMap(HSSFRow recordRow) throws TranFailException {
        Map result = new HashMap();
        String repayStt = "0";
        boolean amtFlag = true;
        boolean amtFlags = true;
        String corName = getCellContent(recordRow, 0, true);
        String reqStt = getCellContent(recordRow, 1, true);
        String orgCode = getCellContent(recordRow, 2, true);
        String financeName = getCellContent(recordRow, 3, true);
        String secendBraUserName = getCellContent(recordRow, 4, true);
        String publishTime = getCellContent(recordRow, 5, true);
        String financeAmt = getCellContent(recordRow, 6, false);
        String financeLimit = getCellContent(recordRow, 7, true);
        String rateBegin = getCellContent(recordRow, 8, false);
        String assureWay = getCellContent(recordRow, 9, true);
        String corContactName = getCellContent(recordRow, 10, true);
        String corContactTel = getCellContent(recordRow, 11, true);
        String incomeLastYear = getCellContent(recordRow, 12, true);
        String salesThisYear = getCellContent(recordRow, 13, true);
        String applyForProduct = getCellContent(recordRow, 14, true);
        String financePurpose = getCellContent(recordRow, 15, true);
        String financeStation = getCellContent(recordRow, 16, true);
        String decomandRemark = getCellContent(recordRow, 17, true);
        String acceptTime = getCellContent(recordRow, 18, true);
        String joinProduct = getCellContent(recordRow, 19, true);
        String openCheckTime = getCellContent(recordRow, 20, true);
        String checkOperationTime = getCellContent(recordRow, 21, true);
        String creditNo = getCellContent(recordRow, 22, false);
        String startDate = getCellContent(recordRow, 23, false);
        String endDate = getCellContent(recordRow, 24, false);
        String assureType = getCellContent(recordRow, 25, false);
        String reGuaOrgCode = getCellContent(recordRow, 26, false);
        String pledgeNo = getCellContent(recordRow, 27, false);
        String patentNo = getCellContent(recordRow, 28, false);
        String creditMoney = getCellContent(recordRow, 29, false);
        String dealUserName = getCellContent(recordRow, 30, false);
        String dealUserPhone = getCellContent(recordRow, 31, false);
        String creditRemark = getCellContent(recordRow, 32, false);
        String creditOperationTime = getCellContent(recordRow, 33, false);
        String loansStartDate = getCellContent(recordRow, 34, false);
        String loansEndDate = getCellContent(recordRow, 35, false);
        String loanContractNum = getCellContent(recordRow, 36, false);
        String lendingRate = getCellContent(recordRow, 37, false);
        String loanAmt = getCellContent(recordRow, 38, false);
        String termOfLoan = getCellContent(recordRow, 39, false);
        String loanOperationTime = getCellContent(recordRow, 40, false);
        String repayAmount = getCellContent(recordRow, 41, false);
        String repayDate = getCellContent(recordRow, 42, false);
        String repayOperationTime = getCellContent(recordRow, 43, false);
        String remark = "";
        if ("".equals(corName) || corName == null) {
            remark = String.valueOf(remark) + " 企业名称为空";
        } else {
            String replace = corName.replace("(", "（").replace(")", "）");
            corName = replace;
            if (replace.length() > 50) {
                remark = String.valueOf(remark) + " 企业名称过长";
            }
        }
        if ("".equals(reqStt) || reqStt == null) {
            remark = String.valueOf(remark) + " 需求状态为空";
        } else if (!"授信".equals(reqStt) && !"放款".equals(reqStt) && !"还款".equals(reqStt)) {
            remark = String.valueOf(remark) + " 需求状态不符合条件";
        }
        if (!"".equals(orgCode) && orgCode != null && !Pattern.compile("^[a-zA-Z0-9[-]]{8,25}").matcher(orgCode).matches()) {
            remark = String.valueOf(remark) + " 统一社会信用代码不符合规则";
        }
        if ("".equals(financeName) || financeName == null) {
            remark = String.valueOf(remark) + " 金融机构为空";
        }
        if ("".equals(secendBraUserName) || secendBraUserName == null) {
            remark = String.valueOf(remark) + " 二级机构联系人姓名为空";
        }
        new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        SimpleDateFormat formatYMD = new SimpleDateFormat("yyyy-MM-dd");
        formatYMD.setLenient(false);
        if ("".equals(publishTime) || publishTime == null) {
            remark = String.valueOf(remark) + " 发布时间为空";
        } else {
            try {
                formatYMD.parse(publishTime);
                publishTime = String.valueOf(publishTime.substring(0, 10)) + " 9:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
            } catch (ParseException unused) {
                remark = String.valueOf(remark) + " 发布时间格式不正确";
            }
        }
        Pattern rex = Pattern.compile("^[1-9]{1}\\d{0,7}$");
        if ("".equals(financeAmt) || financeAmt == null) {
            remark = String.valueOf(remark) + "申请融资金额为空";
        } else if (!rex.matcher(financeAmt).matches()) {
            remark = String.valueOf(remark) + "申请融资金额不符合规则";
        }
        if (!"".equals(financeLimit) && financeLimit != null) {
            if (!Pattern.compile("^[1-9]{1}\\d{0,2}$").matcher(financeLimit).matches()) {
                remark = String.valueOf(remark) + " 融资期限不符合规则";
            } else if (Integer.parseInt(financeLimit) > 360) {
                remark = String.valueOf(remark) + " 融资期限不能大于360";
            }
        }
        Pattern rate = Pattern.compile("^\\d{1,3}(\\.\\d{1,4})?$");
        if (!"".equals(rateBegin) && rateBegin != null && !rate.matcher(rateBegin).matches()) {
            remark = String.valueOf(remark) + " 期望利率不符合规则";
        }
        Pattern tel = Pattern.compile("^((0\\d{2,3}\\-\\d{7,8})|(1[0-9]{10})|(\\d{8}))$");
        if (!"".equals(corContactTel) && corContactTel != null && !tel.matcher(corContactTel).matches()) {
            remark = String.valueOf(remark) + " 联系电话不符合规则";
        }
        Pattern yearReg = Pattern.compile("^[1-9]{1}\\d{0,7}$");
        if (!"".equals(incomeLastYear) && incomeLastYear != null && !yearReg.matcher(incomeLastYear).matches()) {
            remark = String.valueOf(remark) + " 上一年度销售收入不符合规则";
        }
        if (!"".equals(salesThisYear) && salesThisYear != null && !yearReg.matcher(salesThisYear).matches()) {
            remark = String.valueOf(remark) + " 本年度销售收入不符合规则";
        }
        if ("".equals(acceptTime) || acceptTime == null) {
            remark = String.valueOf(remark) + " 受理时间为空";
        } else {
            try {
                formatYMD.parse(acceptTime);
                acceptTime = String.valueOf(acceptTime.substring(0, 10)) + " 10:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
            } catch (ParseException unused2) {
                remark = String.valueOf(remark) + " 受理时间格式不正确";
            }
        }
        if ("".equals(joinProduct) || joinProduct == null) {
            remark = String.valueOf(remark) + " 对接产品为空";
        }
        if ("".equals(openCheckTime) || openCheckTime == null) {
            remark = String.valueOf(remark) + " 启动审核操作时间为空";
        } else {
            try {
                formatYMD.parse(openCheckTime);
                openCheckTime = String.valueOf(openCheckTime.substring(0, 10)) + " 11:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
            } catch (ParseException unused3) {
                remark = String.valueOf(remark) + " 启动审核操作时间格式不正确";
            }
        }
        if ("".equals(checkOperationTime) || checkOperationTime == null) {
            remark = String.valueOf(remark) + " 审核操作时间为空";
        } else {
            try {
                formatYMD.parse(checkOperationTime);
                checkOperationTime = String.valueOf(checkOperationTime.substring(0, 10)) + " 12:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
            } catch (ParseException unused4) {
                remark = String.valueOf(remark) + " 审核操作时间格式不正确";
            }
        }
        SimpleDateFormat formatShort = new SimpleDateFormat("yyyy-MM-dd");
        if ("".equals(startDate) || startDate == null) {
            remark = String.valueOf(remark) + " 授信开始时间为空";
        } else {
            try {
                formatShort.setLenient(false);
                formatShort.parse(startDate);
            } catch (ParseException unused5) {
                remark = String.valueOf(remark) + " 授信开始时间格式不正确";
            }
        }
        Pattern moneyRex = Pattern.compile("^[1-9]{1}\\d{0,4}(\\.\\d{1,6})?$");
        if ("".equals(creditMoney) || creditMoney == null) {
            remark = String.valueOf(remark) + "授信金额为空";
        } else if (!moneyRex.matcher(creditMoney).matches()) {
            remark = String.valueOf(remark) + "授信金额不符合规则";
        }
        if ("".equals(creditOperationTime) || creditOperationTime == null) {
            remark = String.valueOf(remark) + " 授信操作时间为空";
        } else {
            try {
                formatYMD.parse(creditOperationTime);
                creditOperationTime = String.valueOf(creditOperationTime.substring(0, 10)) + " 13:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
            } catch (ParseException unused6) {
                remark = String.valueOf(remark) + " 授信操作时间格式不正确";
            }
        }
        if ("放款".equals(reqStt) || "还款".equals(reqStt)) {
            if ("".equals(loansStartDate) || loansStartDate == null) {
                remark = String.valueOf(remark) + " 贷款起始日为空";
            } else {
                try {
                    formatShort.setLenient(false);
                    formatShort.parse(loansStartDate);
                } catch (ParseException unused7) {
                    remark = String.valueOf(remark) + " 贷款起始日格式不正确";
                }
            }
            if ("".equals(loanAmt) || loanAmt == null) {
                amtFlag = false;
                amtFlags = false;
                remark = String.valueOf(remark) + " 放款金额为空";
            } else if (Double.parseDouble(loanAmt) == 0.0d) {
                amtFlag = false;
                amtFlags = false;
                remark = String.valueOf(remark) + " 放款金额不符合规则";
            } else if (!moneyRex.matcher(loanAmt).matches()) {
                amtFlag = false;
                amtFlags = false;
                remark = String.valueOf(remark) + " 放款金额不符合规则";
            }
            if (amtFlag && Double.parseDouble(loanAmt) > Double.parseDouble(creditMoney)) {
                remark = String.valueOf(remark) + " 放款金额不能大于授信金额";
            }
            if ("".equals(loanOperationTime) || loanOperationTime == null) {
                remark = String.valueOf(remark) + " 放款操作时间为空";
            } else {
                try {
                    formatYMD.parse(loanOperationTime);
                    loanOperationTime = String.valueOf(loanOperationTime.substring(0, 10)) + " 14:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
                } catch (ParseException unused8) {
                    remark = String.valueOf(remark) + " 放款操作时间格式不正确";
                }
            }
        }
        if ("还款".equals(reqStt)) {
            if ("".equals(repayDate) || repayDate == null) {
                remark = String.valueOf(remark) + " 还款时间为空";
            } else {
                try {
                    formatShort.setLenient(false);
                    formatShort.parse(repayDate);
                } catch (ParseException unused9) {
                    remark = String.valueOf(remark) + " 还款时间格式不正确";
                }
            }
            if ("".equals(repayAmount) || repayAmount == null) {
                amtFlags = false;
                remark = String.valueOf(remark) + " 还款金额为空";
            } else if (Double.parseDouble(repayAmount) == 0.0d) {
                amtFlags = false;
                remark = String.valueOf(remark) + " 还款金额不符合规则";
            } else if (!moneyRex.matcher(repayAmount).matches()) {
                amtFlags = false;
                remark = String.valueOf(remark) + " 还款金额不符合规则";
            }
            if (amtFlags) {
                if (Double.parseDouble(repayAmount) > Double.parseDouble(loanAmt)) {
                    remark = String.valueOf(remark) + " 还款金额不能大于放款金额";
                } else if (Double.parseDouble(repayAmount) == Double.parseDouble(loanAmt)) {
                    repayStt = "2";
                } else if (Double.parseDouble(repayAmount) < Double.parseDouble(loanAmt)) {
                    repayStt = "1";
                }
            }
            if ("".equals(repayOperationTime) || repayOperationTime == null) {
                remark = String.valueOf(remark) + " 还款操作时间为空";
            } else {
                try {
                    formatYMD.parse(repayOperationTime);
                    repayOperationTime = String.valueOf(repayOperationTime.substring(0, 10)) + " 15:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
                } catch (ParseException unused10) {
                    remark = String.valueOf(remark) + " 还款操作时间格式不正确";
                }
            }
        }
        result.put("corName", corName);
        result.put("orgCode", orgCode);
        result.put("reqStt", reqStt);
        result.put("financeName", financeName);
        result.put("secendBraUserName", secendBraUserName);
        result.put("publishTime", publishTime);
        result.put("financeAmt", financeAmt);
        result.put("financeLimit", financeLimit);
        result.put("rateBegin", rateBegin);
        result.put("assureWay", assureWay);
        result.put("corContactName", corContactName);
        result.put("corContactTel", corContactTel);
        result.put("incomeLastYear", incomeLastYear);
        result.put("salesThisYear", salesThisYear);
        result.put("applyForProduct", applyForProduct);
        result.put("financePurpose", financePurpose);
        result.put("financeStation", financeStation);
        result.put("decomandRemark", decomandRemark);
        result.put("joinProduct", joinProduct);
        result.put("openCheckTime", openCheckTime);
        result.put("checkOperationTime", checkOperationTime);
        result.put("acceptTime", acceptTime);
        result.put("creditNo", creditNo);
        result.put("startDate", startDate);
        result.put("endDate", endDate);
        result.put("assureType", assureType);
        result.put("reGuaOrgCode", reGuaOrgCode);
        result.put("pledgeNo", pledgeNo);
        result.put("patentNo", patentNo);
        result.put("creditMoney", creditMoney);
        result.put("dealUserName", dealUserName);
        result.put("dealUserPhone", dealUserPhone);
        result.put("creditRemark", creditRemark);
        result.put("creditOperationTime", creditOperationTime);
        result.put("loansStartDate", loansStartDate);
        result.put("loansEndDate", loansEndDate);
        result.put("loanContractNum", loanContractNum);
        result.put("lendingRate", lendingRate);
        result.put("loanAmt", loanAmt);
        result.put("termOfLoan", termOfLoan);
        result.put("loanOperationTime", loanOperationTime);
        result.put("repayAmount", repayAmount);
        result.put("repayDate", repayDate);
        result.put("repayOperationTime", repayOperationTime);
        result.put("repayStt", repayStt);
        result.put("didRemark", remark);
        return result;
    }

    private Map getRecordMap(HSSFRow recordRow, String formatter) throws TranFailException {
        Map result = new HashMap();
        StringTokenizer formatters = new StringTokenizer(formatter, "||");
        int i = 0;
        while (formatters.hasMoreTokens()) {
            String name = (String) formatters.nextElement();
            result.put(name, getCellContent(recordRow, i, true));
            i++;
        }
        return result;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    private String getCellContent(HSSFRow row, int index, boolean toInt) throws TranFailException {
        String result = null;
        try {
            HSSFCell cell = row.getCell(index);
            if (cell != null) {
                switch (cell.getCellType()) {
                    case 0:
                        if (HSSFDateUtil.isCellDateFormatted(cell)) {
                            result = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(HSSFDateUtil.getJavaDate(cell.getNumericCellValue()));
                            break;
                        } else {
                            cell.setCellType(1);
                            result = cell.getRichStringCellValue().getString();
                            break;
                        }
                    case 1:
                        result = cell.getRichStringCellValue().getString();
                        break;
                }
            }
            return result == null ? "" : result.trim();
        } catch (Exception ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
